#
# spec file for package aws-c-sdkutils
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define library_version 1.0.0
%define library_pkg 1_0_0
%define library_soversion 1
Name:           aws-c-sdkutils
Version:        0.2.4
Release:        1.1
Summary:        AWS C SDK Utils
License:        Apache-2.0
Group:          Development/Libraries/C and C++
URL:            https://github.com/awslabs/aws-c-sdkutils
Source0:        https://github.com/awslabs/%{name}/archive/v%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  ninja
BuildRequires:  cmake(aws-c-common)

%description
AWS C SDK Utils

%package -n lib%{name}%{library_pkg}
Summary:        AWS C SDK Utils
Group:          System/Libraries

%description -n lib%{name}%{library_pkg}
AWS C SDK Utils

This package contains the dynamically linked library.

%package devel
Summary:        Development files for aws-c-sdkutils library
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{library_pkg} = %{version}

%description devel
AWS C SDK Utils

This package contains the development files.

%prep
%autosetup -p1

%build
%define __builder ninja
%cmake \
    -DCMAKE_BUILD_TYPE=Release
%make_jobs

%check
export LD_LIBRARY_PATH=%{_builddir}/%{name}-%{version}/build
%ctest

%install
%cmake_install
ln -s lib%{name}.so.%{library_version} %{buildroot}%{_libdir}/lib%{name}.so.%{library_soversion}

%post -n lib%{name}%{library_pkg} -p /sbin/ldconfig
%postun -n lib%{name}%{library_pkg} -p /sbin/ldconfig

%files -n lib%{name}%{library_pkg}
%doc NOTICE README.md
%license LICENSE
%{_libdir}/*.so.%{library_soversion}
%{_libdir}/*.so.%{library_version}

%files devel
%{_libdir}/cmake/
%{_libdir}/*.so
%{_includedir}/*

%changelog
* Mon May 19 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.2.4
  * Make exports consistent by @DmitriyMusatkin in (#52)
  * Fix double free on malformed rulesets by @DmitriyMusatkin in (#53)
* Thu Jan 30 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.2.3
  * A bunch of CMake fixes by @graebm in (#50)
- Drop acs_fix-cmake-modules-path.patch, fixed upstream
* Thu Jan  9 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.2.2
  * Switch CI to use Roles by @DmitriyMusatkin in (#49)
  * Update Config File Parsing Logic to Parse Services
    Section by @waahm7 in (#51)
* Tue Nov 12 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.2.1
  * chore: Modified bug issue template to add checkbox to
    report potential regression. by @ashishdhingra in (#45)
  * Add cxx support by @subdiox in (#48)
* Thu Oct 24 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.2.0
  * Update CMake to 3.9 by @waahm7 in (#47)
* Wed Aug  7 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.1.19
  * Lets make string array const input by @DmitriyMusatkin in (#44)
- from version 0.1.18
  * Switch to more efficient functions for json parsing
    by @DmitriyMusatkin in (#43)
- from version 0.1.17
  * clang-format 18 by @graebm in (#40)
  * Update MacOS to arm64 by @waahm7 in (#41)
  * Add support for string array request parameter to
    endpoint resolution by @DmitriyMusatkin in (#42)
* Tue Jun  4 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.1.16
  * Remove is IPv4/IPv6 functions utils from sdkutils to c-common
    by @waahm7 in (#39)
* Sun Mar 17 2024 Dirk Müller <dmueller@suse.com>
- update to 0.1.15:
  * Fix a bunch of places we forget to aws_raise_error()
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Sat Jan 27 2024 Dirk Müller <dmueller@suse.com>
- fix naming to match shlib policy
* Fri Jan 26 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.1.14
  * Add minimal regex matcher by @DmitriyMusatkin in (#37)
* Wed Dec 13 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.1.13
  * Minor CMakelists.txt cleanup by @graebm in (#34)
  * Added workflow for handling answerable
    discussions by @yasminetalby in (#35)
  * Add partition mapping for iso-e and
    iso-f by @DmitriyMusatkin in (#36)
* Tue Jul 25 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.1.12
  * aws_profile: Reduce logging verbosity of the
    ~/.aws/profile parser by @grrtrr in (#31)
* Wed May 31 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.1.11
  * Update time to ancient by @jmklix in (#29)
  * Update the behavior for profile override by @TingDaoK in (#30)
* Tue May 16 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.1.10
  * Fix warnings in public headers by @waahm7 in (#28)
* Thu May  4 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.1.9
  * Add github templates and bots by @jmklix in (#27)
  * Explicit void parameter for aws_endpoints_rule_engine_init
    by @sdavtaker in (#25)
* Wed Mar 15 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.1.8
  * Fix comment to correct type by @waahm7 in (#21)
  * Add codecov action by @TingDaoK in (#22)
  * Add Reference Count to Profile Collection by @waahm7 in (#23)
  * Update parsing logic to include sso-session by @waahm7 in (#24)
* Tue Nov 22 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.1.7
  * Update CI to fix downstream build by @waahm7 in (#18)
  * Fix handling of description in partitions file by @DmitriyMusatkin in (#20)
* Fri Nov 11 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.1.6
  * Ep2 mem leak by @DmitriyMusatkin in (#19)
- from version 0.1.5
  * Fix build warning in ruleset parser by @DmitriyMusatkin in (#17)
- from version 0.1.4
  * Endpoints20 parsing by @DmitriyMusatkin in (#13)
  * Add AppVerifier to CI by @TwistedTwigleg in (#14)
  * Endpoint Resolution Rule Engine by @DmitriyMusatkin in (#15)
  * Fix bug in resolving templates if strings contain escaped quotes
    by @DmitriyMusatkin in (#16)
* Fri Sep  2 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.1.3
  * Load cmake target fallback by @TingDaoK in (#11)
  * Add readme by @DmitriyMusatkin in (#12)
- Add rpmlint override for bogus shlib-policy-name-error
  * aws-c-sdkutils-rpmlintrc
* Thu Apr 28 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 0.1.2
